# For Haskell Packaging Guidelines see:
# - https://fedoraproject.org/wiki/Packaging:Haskell
# - https://fedoraproject.org/wiki/PackagingDrafts/Haskell

%global pkg_name bytestring-trie

%global common_summary An efficient finite map from (byte)strings to values

%global common_description The implementation is based on big-endian patricia trees, \
like "Data.IntMap". We first trie on the elements of \
"Data.ByteString" and then trie on the big-endian bit \
representation of those elements. Patricia trees have \
efficient algorithms for union and other merging operations, \
but they're also quick for lookups and insertions.

Name:           ghc-%{pkg_name}
Version:        0.2.3
Release:        6%{?dist}
Summary:        %{common_summary}

Group:          System Environment/Libraries
License:        BSD
# BEGIN: cabal2spec-0.24
URL:            http://hackage.haskell.org/package/%{pkg_name}
Source0:        http://hackage.haskell.org/packages/archive/%{pkg_name}/%{version}/%{pkg_name}-%{version}.tar.gz
ExclusiveArch:  %{ghc_arches}
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  hscolour
# END: cabal2spec-0.24

BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-bytestring-devel

%description
%{common_description}


%package -n ghc-%{pkg_name}-devel
Summary:        Development files for %{common_summary}
Group:          Development/Libraries
# BEGIN: cabal2spec-0.24
%{?ghc_devel_requires}
Obsoletes:      ghc-%{pkg_name}-prof < %{version}-%{release}
Provides:       ghc-%{pkg_name}-prof = %{version}-%{release}
# END: cabal2spec-0.24
# remember to require any C devel dependency here
# Haskell devel dependencies are autogenerated by ghc-deps.sh

%description -n ghc-%{pkg_name}-devel
%{common_description}

This package contains the development files.


%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%post -n ghc-%{pkg_name}-devel
%ghc_pkg_recache


%postun -n ghc-%{pkg_name}-devel
%ghc_pkg_recache


%if %{undefined ghc_without_shared}
%files -n ghc-%{pkg_name} -f ghc-%{pkg_name}.files
%defattr(-,root,root,-)
%endif


%files -n ghc-%{pkg_name}-devel -f ghc-%{pkg_name}-devel.files
%defattr(-,root,root,-)


%changelog
* Sat Jul 09 2011 Ben Boeckel <mathstuf@gmail.com> - 0.2.3-6
- Update to cabal2spec-0.24

* Fri Jun 24 2011 Jens Petersen <petersen@redhat.com> - 0.2.3-5
- BR ghc-Cabal-devel instead of ghc-prof and use ghc_arches (cabal2spec-0.23.2)

* Wed May 11 2011 Ben Boeckel <mathstuf@gmail.com> - 0.2.3-4
- Update to cabal2spec-0.22.7

* Tue May 10 2011 Ben Boeckel <mathstuf@gmail.com> - 0.2.3-3
- Update to cabal2spec-0.22.6

* Thu Mar 10 2011 Fabio M. Di Nitto <fdinitto@redhat.com> - 0.2.3-2
- Enable build on sparcv9

* Thu Feb 17 2011 Ben Boeckel <mathstuf@gmail.com> - 0.2.3-1
- Update to 0.2.3

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 15 2011 Ben Boeckel <mathstuf@gmail.com> - 0.2.2-2
- Update to cabal2spec-0.22.4
- Rebuild

* Sat Sep 04 2010 Ben Boeckel <mathstuf@gmail.com> - 0.2.2-1
- Initial package

* Sat Sep  4 2010 Fedora Haskell SIG <haskell-devel@lists.fedoraproject.org> - 0.2.2-0
- initial packaging for Fedora automatically generated by cabal2spec-0.22.2
